@@ -11,10 +11,10 @@ import (
 	"github.com/spf13/cobra"
 	yaml "gopkg.in/yaml.v2"
 
-	cli "github.com/lxc/incus/internal/cmd"
-	"github.com/lxc/incus/internal/i18n"
-	"github.com/lxc/incus/shared/api"
-	"github.com/lxc/incus/shared/termios"
+	cli "github.com/lxc/incus/v6/internal/cmd"
+	"github.com/lxc/incus/v6/internal/i18n"
+	"github.com/lxc/incus/v6/shared/api"
+	"github.com/lxc/incus/v6/shared/termios"
 )
 
 type cmdClusterGroup struct {
@@ -169,6 +169,11 @@ func (c *cmdClusterGroupCreate) Command() *cobra.Command {
 	cmd.Long = cli.FormatSection(i18n.G("Description"), i18n.G(
 		`Create a cluster group`))
 
+	cmd.Example = cli.FormatSection("", i18n.G(`incus cluster group create g1
+
+incus cluster group create g1 < config.yaml
+	Create a cluster group with configuration from config.yaml`))
+
 	cmd.RunE = c.Run
 
 	cmd.ValidArgsFunction = func(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective) {
@@ -184,12 +189,27 @@ func (c *cmdClusterGroupCreate) Command() *cobra.Command {
 
 // It creates new cluster group after performing checks, parsing arguments, and making the server call for creation.
 func (c *cmdClusterGroupCreate) Run(cmd *cobra.Command, args []string) error {
+	var stdinData api.ClusterGroupPut
+
 	// Quick checks.
 	exit, err := c.global.CheckArgs(cmd, args, 1, 1)
 	if exit {
 		return err
 	}
 
+	// If stdin isn't a terminal, read text from it
+	if !termios.IsTerminal(getStdinFd()) {
+		contents, err := io.ReadAll(os.Stdin)
+		if err != nil {
+			return err
+		}
+
+		err = yaml.Unmarshal(contents, &stdinData)
+		if err != nil {
+			return err
+		}
+	}
+
 	// Parse remote
 	resources, err := c.global.ParseServers(args[0])
 	if err != nil {
@@ -204,7 +224,8 @@ func (c *cmdClusterGroupCreate) Run(cmd *cobra.Command, args []string) error {
 
 	// Create the cluster group
 	group := api.ClusterGroupsPost{
-		Name: resource.name,
+		Name:            resource.name,
+		ClusterGroupPut: stdinData,
 	}
 
 	err = resource.server.CreateClusterGroup(group)
