@@ -4,18 +4,17 @@ import (
 	"fmt"
 	"io"
 	"os"
-	"slices"
 	"sort"
 	"strings"
 
 	"github.com/spf13/cobra"
 	"gopkg.in/yaml.v2"
 
-	cli "github.com/lxc/incus/internal/cmd"
-	"github.com/lxc/incus/internal/i18n"
-	"github.com/lxc/incus/shared/api"
-	"github.com/lxc/incus/shared/termios"
-	"github.com/lxc/incus/shared/units"
+	cli "github.com/lxc/incus/v6/internal/cmd"
+	"github.com/lxc/incus/v6/internal/i18n"
+	"github.com/lxc/incus/v6/shared/api"
+	"github.com/lxc/incus/v6/shared/termios"
+	"github.com/lxc/incus/v6/shared/units"
 )
 
 type cmdNetwork struct {
@@ -25,6 +24,11 @@ type cmdNetwork struct {
 	flagType   string
 }
 
+type networkColumn struct {
+	Name string
+	Data func(api.Network) string
+}
+
 func (c *cmdNetwork) Command() *cobra.Command {
 	cmd := &cobra.Command{}
 	cmd.Use = usage("network")
@@ -284,15 +288,27 @@ func (c *cmdNetworkAttachProfile) Run(cmd *cobra.Command, args []string) error {
 		return err
 	}
 
-	// Prepare the profile's device entry
-	device := map[string]string{
-		"type":    "nic",
-		"nictype": "macvlan",
-		"parent":  resource.name,
-	}
+	// Prepare the instance's device entry
+	var device map[string]string
+	if network.Managed && resource.server.HasExtension("instance_nic_network") {
+		// If network is managed, use the network property rather than nictype, so that the network's
+		// inherited properties are loaded into the NIC when started.
+		device = map[string]string{
+			"type":    "nic",
+			"network": network.Name,
+		}
+	} else {
+		// If network is unmanaged default to using a macvlan connected to the specified interface.
+		device = map[string]string{
+			"type":    "nic",
+			"nictype": "macvlan",
+			"parent":  resource.name,
+		}
 
-	if network.Type == "bridge" {
-		device["nictype"] = "bridged"
+		if network.Type == "bridge" {
+			// If the network type is an unmanaged bridge, use bridged NIC type.
+			device["nictype"] = "bridged"
+		}
 	}
 
 	if len(args) > 3 {
@@ -322,6 +338,9 @@ func (c *cmdNetworkCreate) Command() *cobra.Command {
 	cmd.Example = cli.FormatSection("", i18n.G(`incus network create foo
     Create a new network called foo
 
+incus network create foo < config.yaml
+    Create a new network called foo using the content of config.yaml.
+
 incus network create bar network=baz --type ovn
     Create a new OVN network called bar using baz as its uplink network`))
 
@@ -342,12 +361,27 @@ incus network create bar network=baz --type ovn
 }
 
 func (c *cmdNetworkCreate) Run(cmd *cobra.Command, args []string) error {
+	var stdinData api.NetworkPut
+
 	// Quick checks.
 	exit, err := c.global.CheckArgs(cmd, args, 1, -1)
 	if exit {
 		return err
 	}
 
+	// If stdin isn't a terminal, read text from it
+	if !termios.IsTerminal(getStdinFd()) {
+		contents, err := io.ReadAll(os.Stdin)
+		if err != nil {
+			return err
+		}
+
+		err = yaml.Unmarshal(contents, &stdinData)
+		if err != nil {
+			return err
+		}
+	}
+
 	// Parse remote
 	resources, err := c.global.ParseServers(args[0])
 	if err != nil {
@@ -358,11 +392,17 @@ func (c *cmdNetworkCreate) Run(cmd *cobra.Command, args []string) error {
 	client := resource.server
 
 	// Create the network
-	network := api.NetworksPost{}
+	network := api.NetworksPost{
+		NetworkPut: stdinData,
+	}
+
 	network.Name = resource.name
-	network.Config = map[string]string{}
 	network.Type = c.network.flagType
 
+	if network.Config == nil {
+		network.Config = map[string]string{}
+	}
+
 	for i := 1; i < len(args); i++ {
 		entry := strings.SplitN(args[i], "=", 2)
 		if len(entry) < 2 {
@@ -1000,7 +1040,9 @@ type cmdNetworkList struct {
 	global  *cmdGlobal
 	network *cmdNetwork
 
-	flagFormat string
+	flagFormat      string
+	flagColumns     string
+	flagAllProjects bool
 }
 
 func (c *cmdNetworkList) Command() *cobra.Command {
@@ -1009,10 +1051,28 @@ func (c *cmdNetworkList) Command() *cobra.Command {
 	cmd.Aliases = []string{"ls"}
 	cmd.Short = i18n.G("List available networks")
 	cmd.Long = cli.FormatSection(i18n.G("Description"), i18n.G(
-		`List available networks`))
+		`List available networks
 
-	cmd.RunE = c.Run
+The -c option takes a (optionally comma-separated) list of arguments
+that control which image attributes to output when displaying in table
+or csv format.
+
+Default column layout is: ntm46dus
+Column shorthand chars:
+4 - IPv4 address
+6 - IPv6 address
+d - Description
+e - Project name
+m - Managed status
+n - Network Interface Name
+s - State
+t - Interface type
+u - Used by (count)`))
+
+	cmd.Flags().StringVarP(&c.flagColumns, "columns", "c", defaultNetworkColumns, i18n.G("Columns")+"``")
 	cmd.Flags().StringVarP(&c.flagFormat, "format", "f", "table", i18n.G("Format (csv|json|table|yaml|compact)")+"``")
+	cmd.Flags().BoolVar(&c.flagAllProjects, "all-projects", false, i18n.G("List networks in all projects"))
+	cmd.RunE = c.Run
 
 	cmd.ValidArgsFunction = func(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective) {
 		if len(args) != 0 {
@@ -1025,6 +1085,83 @@ func (c *cmdNetworkList) Command() *cobra.Command {
 	return cmd
 }
 
+const defaultNetworkColumns = "ntm46dus"
+
+func (c *cmdNetworkList) parseColumns() ([]networkColumn, error) {
+	columnsShorthandMap := map[rune]networkColumn{
+		'e': {i18n.G("PROJECT"), c.projectColumnData},
+		'n': {i18n.G("NAME"), c.networkNameColumnData},
+		't': {i18n.G("TYPE"), c.typeColumnData},
+		'm': {i18n.G("MANAGED"), c.managedColumnData},
+		'4': {i18n.G("IPV4"), c.ipv4ColumnData},
+		'6': {i18n.G("IPV6"), c.ipv6ColumnData},
+		'd': {i18n.G("DESCRIPTION"), c.descriptionColumnData},
+		'u': {i18n.G("USED BY"), c.usedByColumnData},
+		's': {i18n.G("STATE"), c.stateColumnData},
+	}
+
+	if c.flagColumns == defaultNetworkColumns && c.flagAllProjects {
+		c.flagColumns = "entm46dus"
+	}
+
+	columnList := strings.Split(c.flagColumns, ",")
+
+	columns := []networkColumn{}
+
+	for _, columnEntry := range columnList {
+		if columnEntry == "" {
+			return nil, fmt.Errorf(i18n.G("Empty column entry (redundant, leading or trailing command) in '%s'"), c.flagColumns)
+		}
+
+		for _, columnRune := range columnEntry {
+			column, ok := columnsShorthandMap[columnRune]
+			if !ok {
+				return nil, fmt.Errorf(i18n.G("Unknown column shorthand char '%c' in '%s'"), columnRune, columnEntry)
+			}
+
+			columns = append(columns, column)
+		}
+	}
+
+	return columns, nil
+}
+
+func (c *cmdNetworkList) networkNameColumnData(network api.Network) string {
+	return network.Name
+}
+
+func (c *cmdNetworkList) typeColumnData(network api.Network) string {
+	return network.Type
+}
+
+func (c *cmdNetworkList) managedColumnData(network api.Network) string {
+	return fmt.Sprintf("%v", network.Managed)
+}
+
+func (c *cmdNetworkList) projectColumnData(network api.Network) string {
+	return network.Project
+}
+
+func (c *cmdNetworkList) ipv4ColumnData(network api.Network) string {
+	return network.Config["ipv4.address"]
+}
+
+func (c *cmdNetworkList) ipv6ColumnData(network api.Network) string {
+	return network.Config["ipv6.address"]
+}
+
+func (c *cmdNetworkList) descriptionColumnData(network api.Network) string {
+	return network.Description
+}
+
+func (c *cmdNetworkList) usedByColumnData(network api.Network) string {
+	return fmt.Sprintf("%d", len(network.UsedBy))
+}
+
+func (c *cmdNetworkList) stateColumnData(network api.Network) string {
+	return strings.ToUpper(network.Status)
+}
+
 func (c *cmdNetworkList) Run(cmd *cobra.Command, args []string) error {
 	// Quick checks.
 	exit, err := c.global.CheckArgs(cmd, args, 0, 1)
@@ -1050,48 +1187,40 @@ func (c *cmdNetworkList) Run(cmd *cobra.Command, args []string) error {
 		return fmt.Errorf(i18n.G("Filtering isn't supported yet"))
 	}
 
-	networks, err := resource.server.GetNetworks()
+	var networks []api.Network
+	if c.flagAllProjects {
+		networks, err = resource.server.GetNetworksAllProjects()
+		if err != nil {
+			return err
+		}
+	} else {
+		networks, err = resource.server.GetNetworks()
+		if err != nil {
+			return err
+		}
+	}
+
+	// Parse column flags.
+	columns, err := c.parseColumns()
 	if err != nil {
 		return err
 	}
 
 	data := [][]string{}
 	for _, network := range networks {
-		if slices.Contains([]string{"loopback", "unknown"}, network.Type) {
-			continue
+		line := []string{}
+		for _, column := range columns {
+			line = append(line, column.Data(network))
 		}
 
-		strManaged := i18n.G("NO")
-		if network.Managed {
-			strManaged = i18n.G("YES")
-		}
-
-		strUsedBy := fmt.Sprintf("%d", len(network.UsedBy))
-		details := []string{
-			network.Name,
-			network.Type,
-			strManaged,
-			network.Config["ipv4.address"],
-			network.Config["ipv6.address"],
-			network.Description,
-			strUsedBy,
-			strings.ToUpper(network.Status),
-		}
-
-		data = append(data, details)
+		data = append(data, line)
 	}
 
 	sort.Sort(cli.SortColumnsNaturally(data))
 
-	header := []string{
-		i18n.G("NAME"),
-		i18n.G("TYPE"),
-		i18n.G("MANAGED"),
-		i18n.G("IPV4"),
-		i18n.G("IPV6"),
-		i18n.G("DESCRIPTION"),
-		i18n.G("USED BY"),
-		i18n.G("STATE"),
+	header := []string{}
+	for _, column := range columns {
+		header = append(header, column.Name)
 	}
 
 	return cli.RenderTable(c.flagFormat, header, data, networks)
