@@ -1,6 +1,7 @@
 package main
 
 import (
+	"bufio"
 	"fmt"
 	"io"
 	"os"
@@ -11,14 +12,19 @@ import (
 	"github.com/spf13/cobra"
 	"gopkg.in/yaml.v2"
 
-	cli "github.com/lxc/incus/internal/cmd"
-	"github.com/lxc/incus/internal/i18n"
-	"github.com/lxc/incus/shared/api"
-	"github.com/lxc/incus/shared/termios"
-	"github.com/lxc/incus/shared/units"
-	"github.com/lxc/incus/shared/util"
+	cli "github.com/lxc/incus/v6/internal/cmd"
+	"github.com/lxc/incus/v6/internal/i18n"
+	"github.com/lxc/incus/v6/shared/api"
+	"github.com/lxc/incus/v6/shared/termios"
+	"github.com/lxc/incus/v6/shared/units"
+	"github.com/lxc/incus/v6/shared/util"
 )
 
+type projectColumn struct {
+	Name string
+	Data func(api.Project) string
+}
+
 type cmdProject struct {
 	global *cmdGlobal
 }
@@ -93,6 +99,12 @@ func (c *cmdProjectCreate) Command() *cobra.Command {
 	cmd.Short = i18n.G("Create projects")
 	cmd.Long = cli.FormatSection(i18n.G("Description"), i18n.G(
 		`Create projects`))
+	cmd.Example = cli.FormatSection("", i18n.G(`incus project create p1
+    Create a project named p1
+
+incus project create p1 < config.yaml
+    Create a project named p1 with configuration from config.yaml`))
+
 	cmd.Flags().StringArrayVarP(&c.flagConfig, "config", "c", nil, i18n.G("Config key/value to apply to the new project")+"``")
 
 	cmd.RunE = c.Run
@@ -109,12 +121,27 @@ func (c *cmdProjectCreate) Command() *cobra.Command {
 }
 
 func (c *cmdProjectCreate) Run(cmd *cobra.Command, args []string) error {
+	var stdinData api.ProjectPut
+
 	// Quick checks.
 	exit, err := c.global.CheckArgs(cmd, args, 1, 1)
 	if exit {
 		return err
 	}
 
+	// If stdin isn't a terminal, read text from it
+	if !termios.IsTerminal(getStdinFd()) {
+		contents, err := io.ReadAll(os.Stdin)
+		if err != nil {
+			return err
+		}
+
+		err = yaml.Unmarshal(contents, &stdinData)
+		if err != nil {
+			return err
+		}
+	}
+
 	// Parse remote
 	resources, err := c.global.ParseServers(args[0])
 	if err != nil {
@@ -130,15 +157,18 @@ func (c *cmdProjectCreate) Run(cmd *cobra.Command, args []string) error {
 	// Create the project
 	project := api.ProjectsPost{}
 	project.Name = resource.name
+	project.ProjectPut = stdinData
 
-	project.Config = map[string]string{}
-	for _, entry := range c.flagConfig {
-		key, value, found := strings.Cut(entry, "=")
-		if !found {
-			return fmt.Errorf(i18n.G("Bad key=value pair: %q"), entry)
+	if project.Config == nil {
+		project.Config = map[string]string{}
+		for _, entry := range c.flagConfig {
+			key, value, found := strings.Cut(entry, "=")
+			if !found {
+				return fmt.Errorf(i18n.G("Bad key=value pair: %q"), entry)
+			}
+
+			project.Config[key] = value
 		}
-
-		project.Config[key] = value
 	}
 
 	err = resource.server.CreateProject(project)
@@ -157,6 +187,8 @@ func (c *cmdProjectCreate) Run(cmd *cobra.Command, args []string) error {
 type cmdProjectDelete struct {
 	global  *cmdGlobal
 	project *cmdProject
+
+	flagForce bool
 }
 
 func (c *cmdProjectDelete) Command() *cobra.Command {
@@ -167,6 +199,7 @@ func (c *cmdProjectDelete) Command() *cobra.Command {
 	cmd.Long = cli.FormatSection(i18n.G("Description"), i18n.G(
 		`Delete projects`))
 
+	cmd.Flags().BoolVarP(&c.flagForce, "force", "f", false, i18n.G("Force delete the project and everything it contains."))
 	cmd.RunE = c.Run
 
 	cmd.ValidArgsFunction = func(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective) {
@@ -180,6 +213,20 @@ func (c *cmdProjectDelete) Command() *cobra.Command {
 	return cmd
 }
 
+func (c *cmdProjectDelete) promptConfirmation(name string) error {
+	reader := bufio.NewReader(os.Stdin)
+
+	fmt.Printf(i18n.G("Remove %s and everything it contains (instances, images, volumes, networks, ...) (yes/no): "), name)
+	input, _ := reader.ReadString('\n')
+	input = strings.TrimSuffix(input, "\n")
+
+	if !slices.Contains([]string{i18n.G("yes")}, strings.ToLower(input)) {
+		return fmt.Errorf(i18n.G("User aborted delete operation"))
+	}
+
+	return nil
+}
+
 func (c *cmdProjectDelete) Run(cmd *cobra.Command, args []string) error {
 	// Quick checks.
 	exit, err := c.global.CheckArgs(cmd, args, 1, 1)
@@ -204,10 +251,22 @@ func (c *cmdProjectDelete) Run(cmd *cobra.Command, args []string) error {
 		return fmt.Errorf(i18n.G("Missing project name"))
 	}
 
-	// Delete the project
-	err = resource.server.DeleteProject(resource.name)
-	if err != nil {
-		return err
+	// Delete the project, server is unable to find the project here.
+	if c.flagForce {
+		err := c.promptConfirmation(resource.name)
+		if err != nil {
+			return err
+		}
+
+		err = resource.server.DeleteProjectForce(resource.name)
+		if err != nil {
+			return err
+		}
+	} else {
+		err = resource.server.DeleteProject(resource.name)
+		if err != nil {
+			return err
+		}
 	}
 
 	if !c.global.flagQuiet {
@@ -437,7 +496,8 @@ type cmdProjectList struct {
 	global  *cmdGlobal
 	project *cmdProject
 
-	flagFormat string
+	flagFormat  string
+	flagColumns string
 }
 
 func (c *cmdProjectList) Command() *cobra.Command {
@@ -446,7 +506,26 @@ func (c *cmdProjectList) Command() *cobra.Command {
 	cmd.Aliases = []string{"ls"}
 	cmd.Short = i18n.G("List projects")
 	cmd.Long = cli.FormatSection(i18n.G("Description"), i18n.G(
-		`List projects`))
+		`List projects
+
+The -c option takes a (optionally comma-separated) list of arguments
+that control which image attributes to output when displaying in table
+or csv format.
+Default column layout is: nipvbwzdu
+Column shorthand chars:
+
+n - Project Name
+i - Images
+p - Profiles
+v - Storage Volumes
+b - Storage Buckets
+w - Networks
+z - Network Zones
+d - Description
+u - Used By`))
+
+	cmd.Flags().StringVarP(&c.flagColumns, "columns", "c", defaultProjectColumns, i18n.G("Columns")+"``")
+
 	cmd.Flags().StringVarP(&c.flagFormat, "format", "f", "table", i18n.G("Format (csv|json|table|yaml|compact)")+"``")
 
 	cmd.RunE = c.Run
@@ -462,6 +541,109 @@ func (c *cmdProjectList) Command() *cobra.Command {
 	return cmd
 }
 
+const defaultProjectColumns = "nipvbwzdu"
+
+func (c *cmdProjectList) parseColumns() ([]projectColumn, error) {
+	columnsShorthandMap := map[rune]projectColumn{
+		'n': {i18n.G("NAME"), c.projectNameColumnData},
+		'i': {i18n.G("IMAGES"), c.imagesColumnData},
+		'p': {i18n.G("PROFILES"), c.profilesColumnData},
+		'v': {i18n.G("STORAGE VOLUMES"), c.storageVolumesColumnData},
+		'b': {i18n.G("STORAGE BUCKETS"), c.storageBucketsColumnData},
+		'w': {i18n.G("NETWORKS"), c.networksColumnData},
+		'z': {i18n.G("NETWORK ZONES"), c.networkZonesColumnData},
+		'd': {i18n.G("DESCRIPTION"), c.descriptionColumnData},
+		'u': {i18n.G("USED BY"), c.usedByColumnData},
+	}
+
+	columnList := strings.Split(c.flagColumns, ",")
+
+	columns := []projectColumn{}
+
+	for _, columnEntry := range columnList {
+		if columnEntry == "" {
+			return nil, fmt.Errorf(i18n.G("Empty column entry (redundant, leading or trailing command) in '%s'"), c.flagColumns)
+		}
+
+		for _, columnRune := range columnEntry {
+			column, ok := columnsShorthandMap[columnRune]
+			if !ok {
+				return nil, fmt.Errorf(i18n.G("Unknown column shorthand char '%c' in '%s'"), columnRune, columnEntry)
+			}
+
+			columns = append(columns, column)
+		}
+	}
+
+	return columns, nil
+}
+
+func (c *cmdProjectList) projectNameColumnData(project api.Project) string {
+	return project.Name
+}
+
+func (c *cmdProjectList) imagesColumnData(project api.Project) string {
+	images := i18n.G("NO")
+	if util.IsTrue(project.Config["features.images"]) {
+		images = i18n.G("YES")
+	}
+
+	return images
+}
+
+func (c *cmdProjectList) profilesColumnData(project api.Project) string {
+	profiles := i18n.G("NO")
+	if util.IsTrue(project.Config["features.profiles"]) {
+		profiles = i18n.G("YES")
+	}
+
+	return profiles
+}
+
+func (c *cmdProjectList) storageVolumesColumnData(project api.Project) string {
+	storageVolumes := i18n.G("NO")
+	if util.IsTrue(project.Config["features.storage.volumes"]) {
+		storageVolumes = i18n.G("YES")
+	}
+
+	return storageVolumes
+}
+
+func (c *cmdProjectList) storageBucketsColumnData(project api.Project) string {
+	storageBuckets := i18n.G("NO")
+	if util.IsTrue(project.Config["features.storage.buckets"]) {
+		storageBuckets = i18n.G("YES")
+	}
+
+	return storageBuckets
+}
+
+func (c *cmdProjectList) networksColumnData(project api.Project) string {
+	networks := i18n.G("NO")
+	if util.IsTrue(project.Config["features.networks"]) {
+		networks = i18n.G("YES")
+	}
+
+	return networks
+}
+
+func (c *cmdProjectList) networkZonesColumnData(project api.Project) string {
+	networkZones := i18n.G("NO")
+	if util.IsTrue(project.Config["features.networks.zones"]) {
+		networkZones = i18n.G("YES")
+	}
+
+	return networkZones
+}
+
+func (c *cmdProjectList) descriptionColumnData(project api.Project) string {
+	return project.Description
+}
+
+func (c *cmdProjectList) usedByColumnData(project api.Project) string {
+	return fmt.Sprintf("%d", len(project.UsedBy))
+}
+
 func (c *cmdProjectList) Run(cmd *cobra.Command, args []string) error {
 	conf := c.global.conf
 
@@ -496,59 +678,32 @@ func (c *cmdProjectList) Run(cmd *cobra.Command, args []string) error {
 		return err
 	}
 
+	columns, err := c.parseColumns()
+	if err != nil {
+		return err
+	}
+
 	data := [][]string{}
 	for _, project := range projects {
-		images := i18n.G("NO")
-		if util.IsTrue(project.Config["features.images"]) {
-			images = i18n.G("YES")
+		line := []string{}
+		for _, column := range columns {
+			if column.Name == "NAME" {
+				if project.Name == info.Project {
+					project.Name = fmt.Sprintf("%s (%s)", project.Name, i18n.G("current"))
+				}
+			}
+
+			line = append(line, column.Data(project))
 		}
 
-		profiles := i18n.G("NO")
-		if util.IsTrue(project.Config["features.profiles"]) {
-			profiles = i18n.G("YES")
-		}
-
-		storageVolumes := i18n.G("NO")
-		if util.IsTrue(project.Config["features.storage.volumes"]) {
-			storageVolumes = i18n.G("YES")
-		}
-
-		storageBuckets := i18n.G("NO")
-		if util.IsTrue(project.Config["features.storage.buckets"]) {
-			storageBuckets = i18n.G("YES")
-		}
-
-		networks := i18n.G("NO")
-		if util.IsTrue(project.Config["features.networks"]) {
-			networks = i18n.G("YES")
-		}
-
-		networkZones := i18n.G("NO")
-		if util.IsTrue(project.Config["features.networks.zones"]) {
-			networkZones = i18n.G("YES")
-		}
-
-		name := project.Name
-		if name == info.Project {
-			name = fmt.Sprintf("%s (%s)", name, i18n.G("current"))
-		}
-
-		strUsedBy := fmt.Sprintf("%d", len(project.UsedBy))
-		data = append(data, []string{name, images, profiles, storageVolumes, storageBuckets, networks, networkZones, project.Description, strUsedBy})
+		data = append(data, line)
 	}
 
 	sort.Sort(cli.SortColumnsNaturally(data))
 
-	header := []string{
-		i18n.G("NAME"),
-		i18n.G("IMAGES"),
-		i18n.G("PROFILES"),
-		i18n.G("STORAGE VOLUMES"),
-		i18n.G("STORAGE BUCKETS"),
-		i18n.G("NETWORKS"),
-		i18n.G("NETWORK ZONES"),
-		i18n.G("DESCRIPTION"),
-		i18n.G("USED BY"),
+	header := []string{}
+	for _, column := range columns {
+		header = append(header, column.Name)
 	}
 
 	return cli.RenderTable(c.flagFormat, header, data, projects)
@@ -883,7 +1038,8 @@ type cmdProjectInfo struct {
 	global  *cmdGlobal
 	project *cmdProject
 
-	flagFormat string
+	flagShowAccess bool
+	flagFormat     string
 }
 
 func (c *cmdProjectInfo) Command() *cobra.Command {
@@ -892,6 +1048,7 @@ func (c *cmdProjectInfo) Command() *cobra.Command {
 	cmd.Short = i18n.G("Get a summary of resource allocations")
 	cmd.Long = cli.FormatSection(i18n.G("Description"), i18n.G(
 		`Get a summary of resource allocations`))
+	cmd.Flags().BoolVar(&c.flagShowAccess, "show-access", false, i18n.G("Show the instance's access list"))
 	cmd.Flags().StringVarP(&c.flagFormat, "format", "f", "table", i18n.G("Format (csv|json|table|yaml|compact)")+"``")
 
 	cmd.RunE = c.Run
@@ -926,6 +1083,21 @@ func (c *cmdProjectInfo) Run(cmd *cobra.Command, args []string) error {
 		return fmt.Errorf(i18n.G("Missing project name"))
 	}
 
+	if c.flagShowAccess {
+		access, err := resource.server.GetProjectAccess(resource.name)
+		if err != nil {
+			return err
+		}
+
+		data, err := yaml.Marshal(access)
+		if err != nil {
+			return err
+		}
+
+		fmt.Printf("%s", data)
+		return nil
+	}
+
 	// Get the current allocations
 	projectState, err := resource.server.GetProjectState(resource.name)
 	if err != nil {
