@@ -3,6 +3,7 @@ package main
 import (
 	"bufio"
 	"fmt"
+	"io"
 	"os"
 	"slices"
 	"strings"
@@ -11,11 +12,12 @@ import (
 	"github.com/spf13/cobra"
 	"gopkg.in/yaml.v2"
 
-	"github.com/lxc/incus/client"
-	cli "github.com/lxc/incus/internal/cmd"
-	"github.com/lxc/incus/internal/i18n"
-	"github.com/lxc/incus/internal/instance"
-	"github.com/lxc/incus/shared/api"
+	"github.com/lxc/incus/v6/client"
+	cli "github.com/lxc/incus/v6/internal/cmd"
+	"github.com/lxc/incus/v6/internal/i18n"
+	"github.com/lxc/incus/v6/internal/instance"
+	"github.com/lxc/incus/v6/shared/api"
+	"github.com/lxc/incus/v6/shared/termios"
 )
 
 type cmdSnapshot struct {
@@ -78,9 +80,11 @@ func (c *cmdSnapshotCreate) Command() *cobra.Command {
 
 When --stateful is used, attempt to checkpoint the instance's
 running state, including process memory state, TCP connections, ...`))
-	cmd.Example = cli.FormatSection("", i18n.G(
-		`incus snapshot create u1 snap0
-    Create a snapshot of "u1" called "snap0".`))
+	cmd.Example = cli.FormatSection("", i18n.G(`incus snapshot create u1 snap0
+	Create a snapshot of "u1" called "snap0".
+
+incus snapshot create u1 snap0 < config.yaml
+	Create a snapshot of "u1" called "snap0" with the configuration from "config.yaml".`))
 
 	cmd.Flags().BoolVar(&c.flagStateful, "stateful", false, i18n.G("Whether or not to snapshot the instance's running state"))
 	cmd.Flags().BoolVar(&c.flagNoExpiry, "no-expiry", false, i18n.G("Ignore any configured auto-expiry for the instance"))
@@ -100,6 +104,7 @@ running state, including process memory state, TCP connections, ...`))
 }
 
 func (c *cmdSnapshotCreate) Run(cmd *cobra.Command, args []string) error {
+	var stdinData api.InstanceSnapshotPut
 	conf := c.global.conf
 
 	// Quick checks.
@@ -108,6 +113,19 @@ func (c *cmdSnapshotCreate) Run(cmd *cobra.Command, args []string) error {
 		return err
 	}
 
+	// If stdin isn't a terminal, read text from it
+	if !termios.IsTerminal(getStdinFd()) {
+		contents, err := io.ReadAll(os.Stdin)
+		if err != nil {
+			return err
+		}
+
+		err = yaml.Unmarshal(contents, &stdinData)
+		if err != nil {
+			return err
+		}
+	}
+
 	var snapname string
 	if len(args) < 2 {
 		snapname = ""
@@ -157,6 +175,8 @@ func (c *cmdSnapshotCreate) Run(cmd *cobra.Command, args []string) error {
 
 	if c.flagNoExpiry {
 		req.ExpiresAt = &time.Time{}
+	} else if !stdinData.ExpiresAt.IsZero() {
+		req.ExpiresAt = &stdinData.ExpiresAt
 	}
 
 	op, err := d.CreateInstanceSnapshot(name, req)
@@ -206,7 +226,7 @@ func (c *cmdSnapshotDelete) Run(cmd *cobra.Command, args []string) error {
 	}
 
 	// Parse remote
-	resources, err := c.global.ParseServers(args...)
+	resources, err := c.global.ParseServers(args[0])
 	if err != nil {
 		return err
 	}
@@ -428,11 +448,8 @@ func (c *cmdSnapshotRestore) Command() *cobra.Command {
 
 If --stateful is passed, then the running state will be restored too.`))
 	cmd.Example = cli.FormatSection("", i18n.G(
-		`incus snapshot create u1 snap0
-Create the snapshot.
-
-incus snapshot restore u1 snap0
-Restore the snapshot.`))
+		`incus snapshot restore u1 snap0
+    Restore instance u1 to snapshot snap0`))
 
 	cmd.Flags().BoolVar(&c.flagStateful, "stateful", false, i18n.G("Whether or not to restore the instance's running state from snapshot (if available)"))
 
