@@ -12,11 +12,11 @@ import (
 	"github.com/spf13/cobra"
 	"gopkg.in/yaml.v2"
 
-	cli "github.com/lxc/incus/internal/cmd"
-	"github.com/lxc/incus/internal/i18n"
-	"github.com/lxc/incus/shared/api"
-	"github.com/lxc/incus/shared/termios"
-	"github.com/lxc/incus/shared/units"
+	cli "github.com/lxc/incus/v6/internal/cmd"
+	"github.com/lxc/incus/v6/internal/i18n"
+	"github.com/lxc/incus/v6/shared/api"
+	"github.com/lxc/incus/v6/shared/termios"
+	"github.com/lxc/incus/v6/shared/units"
 )
 
 type cmdStorage struct {
@@ -25,6 +25,11 @@ type cmdStorage struct {
 	flagTarget string
 }
 
+type storageColumn struct {
+	Name string
+	Data func(api.StoragePool) string
+}
+
 func (c *cmdStorage) Command() *cobra.Command {
 	cmd := &cobra.Command{}
 	cmd.Use = usage("storage")
@@ -94,6 +99,11 @@ func (c *cmdStorageCreate) Command() *cobra.Command {
 	cmd.Short = i18n.G("Create storage pools")
 	cmd.Long = cli.FormatSection(i18n.G("Description"), i18n.G(
 		`Create storage pools`))
+	cmd.Example = cli.FormatSection("", i18n.G(`incus create storage s1 dir
+
+incus create storage s1 dir < config.yaml
+    Create a storage pool using the content of config.yaml.
+	`))
 
 	cmd.Flags().StringVar(&c.storage.flagTarget, "target", "", i18n.G("Cluster member name")+"``")
 	cmd.RunE = c.Run
@@ -110,12 +120,33 @@ func (c *cmdStorageCreate) Command() *cobra.Command {
 }
 
 func (c *cmdStorageCreate) Run(cmd *cobra.Command, args []string) error {
+	var stdinData api.StoragePoolPut
+
 	// Quick checks.
 	exit, err := c.global.CheckArgs(cmd, args, 2, -1)
 	if exit {
 		return err
 	}
 
+	// Require a proper driver name.
+	if strings.Contains(args[1], "=") {
+		_ = cmd.Help()
+		return fmt.Errorf(i18n.G("Invalid number of arguments"))
+	}
+
+	// If stdin isn't a terminal, read text from it
+	if !termios.IsTerminal(getStdinFd()) {
+		contents, err := io.ReadAll(os.Stdin)
+		if err != nil {
+			return err
+		}
+
+		err = yaml.Unmarshal(contents, &stdinData)
+		if err != nil {
+			return err
+		}
+	}
+
 	// Parse remote
 	resources, err := c.global.ParseServers(args[0])
 	if err != nil {
@@ -131,13 +162,17 @@ func (c *cmdStorageCreate) Run(cmd *cobra.Command, args []string) error {
 	pool.Config = map[string]string{}
 	pool.Driver = args[1]
 
-	for i := 2; i < len(args); i++ {
-		entry := strings.SplitN(args[i], "=", 2)
-		if len(entry) < 2 {
-			return fmt.Errorf(i18n.G("Bad key=value pair: %s"), entry)
-		}
+	if stdinData.Config == nil {
+		for i := 2; i < len(args); i++ {
+			entry := strings.SplitN(args[i], "=", 2)
+			if len(entry) < 2 {
+				return fmt.Errorf(i18n.G("Bad key=value pair: %s"), entry)
+			}
 
-		pool.Config[entry[0]] = entry[1]
+			pool.Config[entry[0]] = entry[1]
+		}
+	} else {
+		pool.Config = stdinData.Config
 	}
 
 	// If a target member was specified the API won't actually create the
@@ -618,7 +653,8 @@ type cmdStorageList struct {
 	global  *cmdGlobal
 	storage *cmdStorage
 
-	flagFormat string
+	flagFormat  string
+	flagColumns string
 }
 
 func (c *cmdStorageList) Command() *cobra.Command {
@@ -627,7 +663,29 @@ func (c *cmdStorageList) Command() *cobra.Command {
 	cmd.Aliases = []string{"ls"}
 	cmd.Short = i18n.G("List available storage pools")
 	cmd.Long = cli.FormatSection(i18n.G("Description"), i18n.G(
-		`List available storage pools`))
+		`List available storage pools
+
+Default column layout: nDSdus
+
+== Columns ==
+The -c option takes a comma separated list of arguments that control
+which instance attributes to output when displaying in table or csv
+format.
+
+Column arguments are either pre-defined shorthand chars (see below),
+or (extended) config keys.
+
+Commas between consecutive shorthand chars are optional.
+
+Pre-defined column shorthand chars:
+  n - Name
+  D - Driver
+  d - Description
+  S - Source
+  u - used by
+  s - state`))
+	cmd.Flags().StringVarP(&c.flagColumns, "columns", "c", defaultStorageColumns, i18n.G("Columns")+"``")
+
 	cmd.Flags().StringVarP(&c.flagFormat, "format", "f", "table", i18n.G("Format (csv|json|table|yaml|compact)")+"``")
 
 	cmd.RunE = c.Run
@@ -643,6 +701,64 @@ func (c *cmdStorageList) Command() *cobra.Command {
 	return cmd
 }
 
+const defaultStorageColumns = "nDdus"
+
+func (c *cmdStorageList) parseColumns() ([]storageColumn, error) {
+	columnsShorthandMap := map[rune]storageColumn{
+		'n': {i18n.G("NAME"), c.storageNameColumnData},
+		'D': {i18n.G("DRIVER"), c.driverColumnData},
+		'd': {i18n.G("DESCRIPTION"), c.descriptionColumnData},
+		'S': {i18n.G("SOURCE"), c.sourceColumnData},
+		'u': {i18n.G("USED BY"), c.usedByColumnData},
+		's': {i18n.G("STATE"), c.stateColumnData},
+	}
+
+	columnList := strings.Split(c.flagColumns, ",")
+
+	columns := []storageColumn{}
+
+	for _, columnEntry := range columnList {
+		if columnEntry == "" {
+			return nil, fmt.Errorf(i18n.G("Empty column entry (redundant, leading or trailing command) in '%s'"), c.flagColumns)
+		}
+
+		for _, columnRune := range columnEntry {
+			column, ok := columnsShorthandMap[columnRune]
+			if !ok {
+				return nil, fmt.Errorf(i18n.G("Unknown column shorthand char '%c' in '%s'"), columnRune, columnEntry)
+			}
+
+			columns = append(columns, column)
+		}
+	}
+
+	return columns, nil
+}
+
+func (c *cmdStorageList) storageNameColumnData(storage api.StoragePool) string {
+	return storage.Name
+}
+
+func (c *cmdStorageList) driverColumnData(storage api.StoragePool) string {
+	return storage.Driver
+}
+
+func (c *cmdStorageList) descriptionColumnData(storage api.StoragePool) string {
+	return storage.Description
+}
+
+func (c *cmdStorageList) sourceColumnData(storage api.StoragePool) string {
+	return storage.Config["source"]
+}
+
+func (c *cmdStorageList) usedByColumnData(storage api.StoragePool) string {
+	return fmt.Sprintf("%d", len(storage.UsedBy))
+}
+
+func (c *cmdStorageList) stateColumnData(storage api.StoragePool) string {
+	return strings.ToUpper(storage.Status)
+}
+
 func (c *cmdStorageList) Run(cmd *cobra.Command, args []string) error {
 	// Quick checks.
 	exit, err := c.global.CheckArgs(cmd, args, 0, 1)
@@ -669,35 +785,29 @@ func (c *cmdStorageList) Run(cmd *cobra.Command, args []string) error {
 		return err
 	}
 
+	// Parse column flags.
+	columns, err := c.parseColumns()
+	if err != nil {
+		return err
+	}
+
 	data := [][]string{}
 	for _, pool := range pools {
-		usedby := strconv.Itoa(len(pool.UsedBy))
-		details := []string{pool.Name, pool.Driver}
-		if !resource.server.IsClustered() {
-			details = append(details, pool.Config["source"])
+		line := []string{}
+		for _, column := range columns {
+			line = append(line, column.Data(pool))
 		}
 
-		details = append(details, pool.Description)
-		details = append(details, usedby)
-		details = append(details, strings.ToUpper(pool.Status))
-		data = append(data, details)
+		data = append(data, line)
 	}
 
 	sort.Sort(cli.SortColumnsNaturally(data))
 
-	header := []string{
-		i18n.G("NAME"),
-		i18n.G("DRIVER"),
+	header := []string{}
+	for _, column := range columns {
+		header = append(header, column.Name)
 	}
 
-	if !resource.server.IsClustered() {
-		header = append(header, i18n.G("SOURCE"))
-	}
-
-	header = append(header, i18n.G("DESCRIPTION"))
-	header = append(header, i18n.G("USED BY"))
-	header = append(header, i18n.G("STATE"))
-
 	return cli.RenderTable(c.flagFormat, header, data, pools)
 }
 
