@@ -8,26 +8,26 @@ import (
 	"net/http"
 	"os"
 
-	"github.com/lxc/incus/client"
-	"github.com/lxc/incus/internal/revert"
-	"github.com/lxc/incus/internal/server/auth"
-	"github.com/lxc/incus/internal/server/auth/oidc"
-	"github.com/lxc/incus/internal/server/cluster"
-	clusterConfig "github.com/lxc/incus/internal/server/cluster/config"
-	"github.com/lxc/incus/internal/server/config"
-	"github.com/lxc/incus/internal/server/db"
-	instanceDrivers "github.com/lxc/incus/internal/server/instance/drivers"
-	"github.com/lxc/incus/internal/server/lifecycle"
-	"github.com/lxc/incus/internal/server/node"
-	"github.com/lxc/incus/internal/server/request"
-	"github.com/lxc/incus/internal/server/response"
-	scriptletLoad "github.com/lxc/incus/internal/server/scriptlet/load"
-	localUtil "github.com/lxc/incus/internal/server/util"
-	"github.com/lxc/incus/internal/version"
-	"github.com/lxc/incus/shared/api"
-	"github.com/lxc/incus/shared/logger"
-	"github.com/lxc/incus/shared/osarch"
-	localtls "github.com/lxc/incus/shared/tls"
+	"github.com/lxc/incus/v6/client"
+	"github.com/lxc/incus/v6/internal/revert"
+	"github.com/lxc/incus/v6/internal/server/auth"
+	"github.com/lxc/incus/v6/internal/server/auth/oidc"
+	"github.com/lxc/incus/v6/internal/server/cluster"
+	clusterConfig "github.com/lxc/incus/v6/internal/server/cluster/config"
+	"github.com/lxc/incus/v6/internal/server/config"
+	"github.com/lxc/incus/v6/internal/server/db"
+	instanceDrivers "github.com/lxc/incus/v6/internal/server/instance/drivers"
+	"github.com/lxc/incus/v6/internal/server/lifecycle"
+	"github.com/lxc/incus/v6/internal/server/node"
+	"github.com/lxc/incus/v6/internal/server/request"
+	"github.com/lxc/incus/v6/internal/server/response"
+	scriptletLoad "github.com/lxc/incus/v6/internal/server/scriptlet/load"
+	localUtil "github.com/lxc/incus/v6/internal/server/util"
+	"github.com/lxc/incus/v6/internal/version"
+	"github.com/lxc/incus/v6/shared/api"
+	"github.com/lxc/incus/v6/shared/logger"
+	"github.com/lxc/incus/v6/shared/osarch"
+	localtls "github.com/lxc/incus/v6/shared/tls"
 )
 
 var api10Cmd = APIEndpoint{
@@ -67,6 +67,7 @@ var api10 = []APIEndpoint{
 	instanceSnapshotCmd,
 	instanceSnapshotsCmd,
 	instanceStateCmd,
+	instanceAccessCmd,
 	eventsCmd,
 	imageAliasCmd,
 	imageAliasesCmd,
@@ -105,6 +106,7 @@ var api10 = []APIEndpoint{
 	projectCmd,
 	projectsCmd,
 	projectStateCmd,
+	projectAccessCmd,
 	storagePoolCmd,
 	storagePoolResourcesCmd,
 	storagePoolsCmd,
