@@ -73,7 +73,6 @@ profile "{{ .name }}" flags=(attach_disconnected,mediate_deleted) {
   deny /proc/kcore rwklx,
   deny /proc/sysrq-trigger rwklx,
   deny /proc/acpi/** rwklx,
-  deny /proc/sys/fs/** wklx,
 
   # Handle securityfs (access handled separately)
   mount fstype=securityfs -> /sys/kernel/security/,
@@ -322,7 +321,21 @@ profile "{{ .name }}" flags=(attach_disconnected,mediate_deleted) {
   mount options=(rw,move) /sys?*{,/**},
 
   # Block dangerous paths under /proc/sys
-  deny /proc/sys/[^kn]*{,/**} wklx,
+  deny /proc/sys/[^fkn]*{,/**} wklx,
+  deny /proc/sys/f[^s]*{,/**} wklx,
+  deny /proc/sys/fs/[^b]*{,/**} wklx,
+  deny /proc/sys/fs/b[^i]*{,/**} wklx,
+  deny /proc/sys/fs/bi[^n]*{,/**} wklx,
+  deny /proc/sys/fs/bin[^f]*{,/**} wklx,
+  deny /proc/sys/fs/binf[^m]*{,/**} wklx,
+  deny /proc/sys/fs/binfm[^t]*{,/**} wklx,
+  deny /proc/sys/fs/binfmt[^_]*{,/**} wklx,
+  deny /proc/sys/fs/binfmt_[^m]*{,/**} wklx,
+  deny /proc/sys/fs/binfmt_m[^i]*{,/**} wklx,
+  deny /proc/sys/fs/binfmt_mi[^s]*{,/**} wklx,
+  deny /proc/sys/fs/binfmt_mis[^c]*{,/**} wklx,
+  deny /proc/sys/fs/binfmt_misc?*{,/**} wklx,
+  deny /proc/sys/fs?*{,/**} wklx,
   deny /proc/sys/k[^e]*{,/**} wklx,
   deny /proc/sys/ke[^r]*{,/**} wklx,
   deny /proc/sys/ker[^n]*{,/**} wklx,
@@ -391,7 +404,7 @@ profile "{{ .name }}" flags=(attach_disconnected,mediate_deleted) {
   deny /sys/devices/virtual?*{,/**} wklx,
   deny /sys/devices?*{,/**} wklx,
   deny /sys/f[^s]*{,/**} wklx,
-  deny /sys/fs/[^cb]*{,/**} wklx,
+  deny /sys/fs/[^bc]*{,/**} wklx,
   deny /sys/fs/b[^p]*{,/**} wklx,
   deny /sys/fs/bp[^f]*{,/**} wklx,
   deny /sys/fs/bpf?*{,/**} wklx,
@@ -497,14 +510,14 @@ profile "{{ .name }}" flags=(attach_disconnected,mediate_deleted) {
   pivot_root,
 
   # Allow modifying mount propagation
-  mount options=(rw,slave) -> **,
-  mount options=(rw,rslave) -> **,
-  mount options=(rw,shared) -> **,
-  mount options=(rw,rshared) -> **,
-  mount options=(rw,private) -> **,
-  mount options=(rw,rprivate) -> **,
-  mount options=(rw,unbindable) -> **,
-  mount options=(rw,runbindable) -> **,
+  mount options=(rw,slave) -> /**,
+  mount options=(rw,rslave) -> /**,
+  mount options=(rw,shared) -> /**,
+  mount options=(rw,rshared) -> /**,
+  mount options=(rw,private) -> /**,
+  mount options=(rw,rprivate) -> /**,
+  mount options=(rw,unbindable) -> /**,
+  mount options=(rw,runbindable) -> /**,
 
   # Allow all bind-mounts.
   mount options=(rw,bind) -> /**,
@@ -534,6 +547,9 @@ profile "{{ .name }}" flags=(attach_disconnected,mediate_deleted) {
   mount options=(ro,remount,bind,noatime,nosuid,noexec,nodev),
   mount options=(ro,remount,bind,nosuid,noexec,strictatime),
   mount options=(ro,remount,nosuid,noexec,strictatime),
+{{- if .feature_nosymfollow }}
+  mount options=(ro,remount,bind,nosuid,noexec,nodev,nosymfollow),
+{{- end }}
 
   # Allow remounting things read-only
   mount options=(ro,remount) /,
