@@ -13,9 +13,9 @@ import (
 	"github.com/openfga/go-sdk/client"
 	"github.com/openfga/go-sdk/credentials"
 
-	"github.com/lxc/incus/internal/server/certificate"
-	"github.com/lxc/incus/shared/api"
-	"github.com/lxc/incus/shared/logger"
+	"github.com/lxc/incus/v6/internal/server/certificate"
+	"github.com/lxc/incus/v6/shared/api"
+	"github.com/lxc/incus/v6/shared/logger"
 )
 
 type fga struct {
@@ -965,7 +965,7 @@ func (f *fga) syncResources(ctx context.Context, resources Resources) error {
 	// Check if the type-bound public access is set.
 	resp, err := f.client.Check(ctx).Body(client.ClientCheckRequest{
 		User:     "user:*",
-		Relation: relationUser,
+		Relation: "viewer",
 		Object:   ObjectServer().String(),
 	}).Execute()
 	if err != nil {
@@ -976,7 +976,7 @@ func (f *fga) syncResources(ctx context.Context, resources Resources) error {
 	if !resp.GetAllowed() {
 		writes = append(writes, client.ClientTupleKey{
 			User:     "user:*",
-			Relation: relationUser,
+			Relation: "viewer",
 			Object:   ObjectServer().String(),
 		})
 	}
@@ -1108,3 +1108,113 @@ func (f *fga) syncResources(ctx context.Context, resources Resources) error {
 	// Perform any necessary writes and deletions against the OpenFGA server.
 	return f.updateTuples(ctx, writes, deletions)
 }
+
+// GetInstanceAccess returns the list of entities who have access to the instance.
+func (f *fga) GetInstanceAccess(ctx context.Context, projectName string, instanceName string) (*api.Access, error) {
+	// Get all the entries from OpenFGA.
+	entries := map[string]string{}
+
+	userFilters := []openfga.UserTypeFilter{{Type: "user"}}
+	relations := []string{"admin", "operator", "user", "viewer"}
+	for _, relation := range relations {
+		resp, err := f.client.ListUsers(ctx).Body(client.ClientListUsersRequest{
+			Object: openfga.FgaObject{
+				Type: "instance",
+				Id:   fmt.Sprintf("%s/%s", projectName, instanceName),
+			},
+			Relation:    relation,
+			UserFilters: userFilters,
+		}).Execute()
+
+		if err != nil {
+			fgaAPIErr, ok := err.(openfga.FgaApiValidationError)
+			if !ok || fgaAPIErr.ResponseCode() != openfga.RELATION_NOT_FOUND {
+				fgaNotFoundErr, ok := err.(openfga.FgaApiNotFoundError)
+				if ok && fgaNotFoundErr.ResponseCode() == openfga.UNDEFINED_ENDPOINT {
+					return nil, fmt.Errorf("OpenFGA server doesn't support listing users")
+				}
+
+				return nil, fmt.Errorf("Failed to list objects with relation %q: %w: %T", relation, err, err)
+			}
+		}
+
+		for _, user := range resp.GetUsers() {
+			obj := user.GetObject()
+			if obj.Id == "" {
+				continue
+			}
+
+			_, ok := entries[obj.Id]
+			if !ok {
+				entries[obj.Id] = relation
+			}
+		}
+	}
+
+	// Convert to our access records.
+	access := api.Access{}
+	for user, relation := range entries {
+		access = append(access, api.AccessEntry{
+			Identifier: user,
+			Role:       relation,
+			Provider:   "openfga",
+		})
+	}
+
+	return &access, nil
+}
+
+// GetProjectAccess returns the list of entities who have access to the project.
+func (f *fga) GetProjectAccess(ctx context.Context, projectName string) (*api.Access, error) {
+	// Get all the entries from OpenFGA.
+	entries := map[string]string{}
+
+	userFilters := []openfga.UserTypeFilter{{Type: "user"}}
+	relations := []string{"admin", "operator", "user", "viewer"}
+	for _, relation := range relations {
+		resp, err := f.client.ListUsers(ctx).Body(client.ClientListUsersRequest{
+			Object: openfga.FgaObject{
+				Type: "project",
+				Id:   projectName,
+			},
+			Relation:    relation,
+			UserFilters: userFilters,
+		}).Execute()
+
+		if err != nil {
+			fgaAPIErr, ok := err.(openfga.FgaApiValidationError)
+			if !ok || fgaAPIErr.ResponseCode() != openfga.RELATION_NOT_FOUND {
+				fgaNotFoundErr, ok := err.(openfga.FgaApiNotFoundError)
+				if ok && fgaNotFoundErr.ResponseCode() == openfga.UNDEFINED_ENDPOINT {
+					return nil, fmt.Errorf("OpenFGA server doesn't support listing users")
+				}
+
+				return nil, fmt.Errorf("Failed to list objects with relation %q: %w: %T", relation, err, err)
+			}
+		}
+
+		for _, user := range resp.GetUsers() {
+			obj := user.GetObject()
+			if obj.Id == "" {
+				continue
+			}
+
+			_, ok := entries[obj.Id]
+			if !ok {
+				entries[obj.Id] = relation
+			}
+		}
+	}
+
+	// Convert to our access records.
+	access := api.Access{}
+	for user, relation := range entries {
+		access = append(access, api.AccessEntry{
+			Identifier: user,
+			Role:       relation,
+			Provider:   "openfga",
+		})
+	}
+
+	return &access, nil
+}
