@@ -14,16 +14,16 @@ import (
 	"github.com/cowsql/go-cowsql/app"
 	"github.com/cowsql/go-cowsql/client"
 
-	"github.com/lxc/incus/internal/server/certificate"
-	"github.com/lxc/incus/internal/server/db"
-	"github.com/lxc/incus/internal/server/db/cluster"
-	"github.com/lxc/incus/internal/server/node"
-	"github.com/lxc/incus/internal/server/state"
-	internalUtil "github.com/lxc/incus/internal/util"
-	"github.com/lxc/incus/internal/version"
-	"github.com/lxc/incus/shared/logger"
-	localtls "github.com/lxc/incus/shared/tls"
-	"github.com/lxc/incus/shared/util"
+	"github.com/lxc/incus/v6/internal/server/certificate"
+	"github.com/lxc/incus/v6/internal/server/db"
+	"github.com/lxc/incus/v6/internal/server/db/cluster"
+	"github.com/lxc/incus/v6/internal/server/node"
+	"github.com/lxc/incus/v6/internal/server/state"
+	internalUtil "github.com/lxc/incus/v6/internal/util"
+	"github.com/lxc/incus/v6/internal/version"
+	"github.com/lxc/incus/v6/shared/logger"
+	localtls "github.com/lxc/incus/v6/shared/tls"
+	"github.com/lxc/incus/v6/shared/util"
 )
 
 // clusterBusyError is returned by dqlite if attempting attempting to join a cluster at the same time as a role-change.
@@ -524,7 +524,8 @@ func Join(state *state.State, gateway *Gateway, networkCert *localtls.CertInfo,
 			for name, id := range network {
 				config, ok := networks[name]
 				if !ok {
-					return fmt.Errorf("Joining member has no config for network %s", name)
+					// Not all networks are present as virtual networks (OVN) don't need entries.
+					continue
 				}
 
 				err := tx.NetworkNodeJoin(id, node.ID)
