@@ -10,9 +10,9 @@ import (
 	"path/filepath"
 	"strings"
 
-	"github.com/lxc/incus/internal/server/db/generate/file"
-	"github.com/lxc/incus/internal/server/db/generate/lex"
-	"github.com/lxc/incus/shared/util"
+	"github.com/lxc/incus/v6/internal/server/db/generate/file"
+	"github.com/lxc/incus/v6/internal/server/db/generate/lex"
+	"github.com/lxc/incus/v6/shared/util"
 )
 
 // Method generates a code snippet for a particular database query method.
