@@ -9,16 +9,16 @@ import (
 	"strings"
 	"time"
 
-	"github.com/lxc/incus/internal/revert"
-	"github.com/lxc/incus/internal/server/db"
-	"github.com/lxc/incus/internal/server/db/cluster"
-	"github.com/lxc/incus/internal/server/instance"
-	"github.com/lxc/incus/internal/server/network/ovn"
-	"github.com/lxc/incus/internal/server/state"
-	"github.com/lxc/incus/shared/api"
-	"github.com/lxc/incus/shared/logger"
-	"github.com/lxc/incus/shared/util"
-	"github.com/lxc/incus/shared/validate"
+	"github.com/lxc/incus/v6/internal/revert"
+	"github.com/lxc/incus/v6/internal/server/db"
+	"github.com/lxc/incus/v6/internal/server/db/cluster"
+	"github.com/lxc/incus/v6/internal/server/instance"
+	"github.com/lxc/incus/v6/internal/server/network/ovn"
+	"github.com/lxc/incus/v6/internal/server/state"
+	"github.com/lxc/incus/v6/shared/api"
+	"github.com/lxc/incus/v6/shared/logger"
+	"github.com/lxc/incus/v6/shared/util"
+	"github.com/lxc/incus/v6/shared/validate"
 )
 
 // OVN ACL rule priorities.
@@ -440,7 +440,10 @@ func ovnRuleCriteriaToOVNACLRule(direction string, rule *api.NetworkACLRule, por
 	// Populate Action and Priority based on rule's Action.
 	switch rule.Action {
 	case "allow":
-		portGroupRule.Action = "allow-related" // TODO add stateless support.
+		portGroupRule.Action = "allow-related"
+		portGroupRule.Priority = ovnACLPriorityPortGroupAllow
+	case "allow-stateless":
+		portGroupRule.Action = "allow-stateless"
 		portGroupRule.Priority = ovnACLPriorityPortGroupAllow
 	case "reject":
 		portGroupRule.Action = "reject"
