@@ -12,9 +12,9 @@ import (
 	ovsModel "github.com/ovn-org/libovsdb/model"
 	"github.com/ovn-org/libovsdb/ovsdb"
 
-	"github.com/lxc/incus/internal/iprange"
-	ovnNB "github.com/lxc/incus/internal/server/network/ovn/schema/ovn-nb"
-	"github.com/lxc/incus/shared/util"
+	"github.com/lxc/incus/v6/internal/iprange"
+	ovnNB "github.com/lxc/incus/v6/internal/server/network/ovn/schema/ovn-nb"
+	"github.com/lxc/incus/v6/shared/util"
 )
 
 // OVNRouter OVN router name.
@@ -182,15 +182,40 @@ type OVNRouterPeering struct {
 	TargetRouterRoutes  []net.IPNet
 }
 
-// LogicalRouterAdd adds a named logical router.
-func (o *NB) LogicalRouterAdd(routerName OVNRouter, mayExist bool) error {
-	args := []string{}
-
-	if mayExist {
-		args = append(args, "--may-exist")
+// CreateLogicalRouter adds a named logical router.
+// If mayExist is true, then an existing resource of the same name is not treated as an error.
+func (o *NB) CreateLogicalRouter(ctx context.Context, routerName OVNRouter, mayExist bool) error {
+	logicalRouter := ovnNB.LogicalRouter{
+		Name: string(routerName),
 	}
 
-	_, err := o.nbctl(append(args, "lr-add", string(routerName))...)
+	// Check if already exists.
+	err := o.get(ctx, &logicalRouter)
+	if err != nil && err != ErrNotFound {
+		return err
+	}
+
+	if logicalRouter.UUID != "" {
+		if mayExist {
+			return nil
+		}
+
+		return ErrExists
+	}
+
+	// Create the record.
+	operations, err := o.client.Create(&logicalRouter)
+	if err != nil {
+		return err
+	}
+
+	// Apply the changes.
+	resp, err := o.client.Transact(ctx, operations...)
+	if err != nil {
+		return err
+	}
+
+	_, err = ovsdb.CheckOperationResults(resp, operations)
 	if err != nil {
 		return err
 	}
@@ -198,9 +223,34 @@ func (o *NB) LogicalRouterAdd(routerName OVNRouter, mayExist bool) error {
 	return nil
 }
 
-// LogicalRouterDelete deletes a named logical router.
-func (o *NB) LogicalRouterDelete(routerName OVNRouter) error {
-	_, err := o.nbctl("--if-exists", "lr-del", string(routerName))
+// DeleteLogicalRouter deletes a named logical router.
+func (o *NB) DeleteLogicalRouter(ctx context.Context, routerName OVNRouter) error {
+	logicalRouter := ovnNB.LogicalRouter{
+		Name: string(routerName),
+	}
+
+	err := o.get(ctx, &logicalRouter)
+	if err != nil {
+		// Logical router is already gone.
+		if err == ErrNotFound {
+			return nil
+		}
+
+		return err
+	}
+
+	operations, err := o.client.Where(&logicalRouter).Delete()
+	if err != nil {
+		return err
+	}
+
+	// Apply the changes.
+	resp, err := o.client.Transact(ctx, operations...)
+	if err != nil {
+		return err
+	}
+
+	_, err = ovsdb.CheckOperationResults(resp, operations)
 	if err != nil {
 		return err
 	}
@@ -208,63 +258,94 @@ func (o *NB) LogicalRouterDelete(routerName OVNRouter) error {
 	return nil
 }
 
-// LogicalRouterSNATAdd adds an SNAT rule to a logical router to translate packets from intNet to extIP.
-func (o *NB) LogicalRouterSNATAdd(routerName OVNRouter, intNet *net.IPNet, extIP net.IP, mayExist bool) error {
-	args := []string{}
+// CreateLogicalRouterNAT adds an SNAT or DNAT rule to a logical router to translate packets from intNet to extIP.
+func (o *NB) CreateLogicalRouterNAT(ctx context.Context, routerName OVNRouter, natType string, intNet *net.IPNet, extIP net.IP, intIP net.IP, stateless bool, mayExist bool) error {
+	// Prepare the addresses.
+	var logicalIP string
+	var externalIP string
 
-	if mayExist {
-		args = append(args, "--if-exists", "lr-nat-del", string(routerName), "snat", extIP.String(), "--")
+	if natType == "snat" {
+		logicalIP = intNet.String()
+		externalIP = extIP.String()
+	} else if natType == "dnat_and_snat" {
+		logicalIP = intIP.String()
+		externalIP = extIP.String()
+	} else {
+		return fmt.Errorf("Invalid NAT rule type %q", natType)
 	}
 
-	_, err := o.nbctl(append(args, "lr-nat-add", string(routerName), "snat", extIP.String(), intNet.String())...)
+	logicalRouter := ovnNB.LogicalRouter{
+		Name: string(routerName),
+	}
+
+	// Make sure logical router exists.
+	err := o.get(ctx, &logicalRouter)
 	if err != nil {
 		return err
 	}
 
-	return nil
-}
+	// Check if the rule already exists.
+	for _, natUUID := range logicalRouter.Nat {
+		natRule := ovnNB.NAT{
+			UUID: natUUID,
+		}
 
-// LogicalRouterDNATSNATDeleteAll deletes all DNAT_AND_SNAT rules from a logical router.
-func (o *NB) LogicalRouterDNATSNATDeleteAll(routerName OVNRouter) error {
-	_, err := o.nbctl("--if-exists", "lr-nat-del", string(routerName), "dnat_and_snat")
-	if err != nil {
-		return err
-	}
-
-	return nil
-}
-
-// LogicalRouterSNATDeleteAll deletes all SNAT rules from a logical router.
-func (o *NB) LogicalRouterSNATDeleteAll(routerName OVNRouter) error {
-	_, err := o.nbctl("--if-exists", "lr-nat-del", string(routerName), "snat")
-	if err != nil {
-		return err
-	}
-
-	return nil
-}
-
-// LogicalRouterDNATSNATAdd adds a DNAT_AND_SNAT rule to a logical router to translate packets from extIP to intIP.
-func (o *NB) LogicalRouterDNATSNATAdd(routerName OVNRouter, extIP net.IP, intIP net.IP, stateless bool, mayExist bool) error {
-	if mayExist {
-		// There appears to be a bug in ovn-nbctl where running lr-nat-del as part of the same command as
-		// lr-nat-add doesn't take account the changes by lr-nat-del, and so you can end up with errors
-		// if a NAT entry already exists. So we run them as separate command invocations.
-		// There can be left over dnat_and_snat entries if an instance was stopped when the ovn-nb DB
-		// was not reachable.
-		_, err := o.nbctl("--if-exists", "lr-nat-del", string(routerName), "dnat_and_snat", extIP.String())
+		err = o.get(ctx, &natRule)
 		if err != nil {
 			return err
 		}
+
+		// Check if rule is of the requested type.
+		if natRule.Type != natType {
+			continue
+		}
+
+		// Check if matching our new rule.
+		if natRule.LogicalIP == logicalIP && natRule.ExternalIP == externalIP {
+			if mayExist {
+				return nil
+			}
+
+			return ErrExists
+		}
 	}
 
-	args := []string{}
-
-	if stateless {
-		args = append(args, "--stateless")
+	natRule := ovnNB.NAT{
+		UUID:       "nat",
+		Options:    map[string]string{"stateless": fmt.Sprintf("%v", stateless)},
+		Type:       natType,
+		LogicalIP:  logicalIP,
+		ExternalIP: externalIP,
 	}
 
-	_, err := o.nbctl(append(args, "lr-nat-add", string(routerName), "dnat_and_snat", extIP.String(), intIP.String())...)
+	operations := []ovsdb.Operation{}
+
+	createOps, err := o.client.Create(&natRule)
+	if err != nil {
+		return err
+	}
+
+	operations = append(operations, createOps...)
+
+	// Add it to the router.
+	updateOps, err := o.client.Where(&logicalRouter).Mutate(&logicalRouter, ovsModel.Mutation{
+		Field:   &logicalRouter.Nat,
+		Mutator: ovsdb.MutateOperationInsert,
+		Value:   []string{natRule.UUID},
+	})
+	if err != nil {
+		return err
+	}
+
+	operations = append(operations, updateOps...)
+
+	// Apply the changes.
+	resp, err := o.client.Transact(ctx, operations...)
+	if err != nil {
+		return err
+	}
+
+	_, err = ovsdb.CheckOperationResults(resp, operations)
 	if err != nil {
 		return err
 	}
@@ -272,19 +353,89 @@ func (o *NB) LogicalRouterDNATSNATAdd(routerName OVNRouter, extIP net.IP, intIP
 	return nil
 }
 
-// LogicalRouterDNATSNATDelete deletes a DNAT_AND_SNAT rule from a logical router.
-func (o *NB) LogicalRouterDNATSNATDelete(routerName OVNRouter, extIPs ...net.IP) error {
-	args := []string{}
-
-	for _, extIP := range extIPs {
-		if len(args) > 0 {
-			args = append(args, "--")
-		}
-
-		args = append(args, "--if-exists", "lr-nat-del", string(routerName), "dnat_and_snat", extIP.String())
+// DeleteLogicalRouterNAT deletes all NAT rules of a particular type from a logical router.
+func (o *NB) DeleteLogicalRouterNAT(ctx context.Context, routerName OVNRouter, natType string, all bool, extIPs ...net.IP) error {
+	// Quick checks.
+	if all && len(extIPs) != 0 {
+		return fmt.Errorf("Can't ask for all NAT rules to be deleted and specify specific addresses")
 	}
 
-	_, err := o.nbctl(args...)
+	logicalRouter := ovnNB.LogicalRouter{
+		Name: string(routerName),
+	}
+
+	// Make sure logical router exists.
+	err := o.get(ctx, &logicalRouter)
+	if err != nil {
+		return err
+	}
+
+	operations := []ovsdb.Operation{}
+
+	// Go through all rules.
+	for _, natUUID := range logicalRouter.Nat {
+		natRule := ovnNB.NAT{
+			UUID: natUUID,
+		}
+
+		err = o.get(ctx, &natRule)
+		if err != nil {
+			return err
+		}
+
+		// Check if rule is of the requested type.
+		if natRule.Type != natType {
+			continue
+		}
+
+		// Check if the address matches.
+		if !all {
+			found := false
+			for _, extIP := range extIPs {
+				if natRule.ExternalIP == extIP.String() {
+					found = true
+					break
+				}
+			}
+
+			if !found {
+				continue
+			}
+		}
+
+		// Delete the rule.
+		deleteOps, err := o.client.Where(&natRule).Delete()
+		if err != nil {
+			return err
+		}
+
+		operations = append(operations, deleteOps...)
+
+		// Delete the entry from the logical router.
+		deleteOps, err = o.client.Where(&logicalRouter).Mutate(&logicalRouter, ovsModel.Mutation{
+			Field:   &logicalRouter.Nat,
+			Mutator: ovsdb.MutateOperationDelete,
+			Value:   []string{natRule.UUID},
+		})
+
+		if err != nil {
+			return err
+		}
+
+		operations = append(operations, deleteOps...)
+	}
+
+	if len(operations) == 0 {
+		return nil
+	}
+
+	// Apply the changes.
+	resp, err := o.client.Transact(ctx, operations...)
+	if err != nil {
+		return err
+	}
+
+	_, err = ovsdb.CheckOperationResults(resp, operations)
 	if err != nil {
 		return err
 	}
