@@ -14,15 +14,15 @@ import (
 
 	"golang.org/x/sys/unix"
 
-	internalInstance "github.com/lxc/incus/internal/instance"
-	"github.com/lxc/incus/internal/linux"
-	"github.com/lxc/incus/internal/server/operations"
-	internalUtil "github.com/lxc/incus/internal/util"
-	"github.com/lxc/incus/shared/api"
-	"github.com/lxc/incus/shared/idmap"
-	"github.com/lxc/incus/shared/logger"
-	"github.com/lxc/incus/shared/subprocess"
-	"github.com/lxc/incus/shared/util"
+	internalInstance "github.com/lxc/incus/v6/internal/instance"
+	"github.com/lxc/incus/v6/internal/linux"
+	"github.com/lxc/incus/v6/internal/server/operations"
+	internalUtil "github.com/lxc/incus/v6/internal/util"
+	"github.com/lxc/incus/v6/shared/api"
+	"github.com/lxc/incus/v6/shared/idmap"
+	"github.com/lxc/incus/v6/shared/logger"
+	"github.com/lxc/incus/v6/shared/subprocess"
+	"github.com/lxc/incus/v6/shared/util"
 )
 
 // MinBlockBoundary minimum block boundary size to use.
@@ -880,3 +880,60 @@ func wipeBlockHeaders(path string) error {
 func IsContentBlock(contentType ContentType) bool {
 	return contentType == ContentTypeBlock || contentType == ContentTypeISO
 }
+
+// NewSparseFileWrapper returns a SparseFileWrapper for the provided io.File.
+func NewSparseFileWrapper(w *os.File) *SparseFileWrapper {
+	return &SparseFileWrapper{w: w}
+}
+
+// SparseFileWrapper wraps os.File to create sparse Files.
+type SparseFileWrapper struct {
+	w *os.File
+}
+
+// Write performs the write but skips null bytes.
+func (sfw *SparseFileWrapper) Write(p []byte) (n int, err error) {
+	originalLength := len(p)
+	start := 0
+
+	for start < len(p) {
+		end := start
+		if p[start] == 0 {
+			for end < len(p) && p[end] == 0 {
+				end++
+			}
+
+			_, err := sfw.w.Seek(int64(end-start), io.SeekCurrent)
+			if err != nil {
+				return start, err
+			}
+
+			start = end
+		} else {
+			// Write non-zero bytes
+			for end < len(p) && p[end] != 0 {
+				end++
+			}
+
+			written, err := sfw.w.Write(p[start:end])
+			if err != nil {
+				return start + written, err
+			}
+
+			start = end
+		}
+	}
+
+	return originalLength, nil
+}
+
+// sliceAny returns true when any element in a slice satisfy a predicate.
+func sliceAny[T any](slice []T, predicate func(T) bool) bool {
+	for _, element := range slice {
+		if predicate(element) {
+			return true
+		}
+	}
+
+	return false
+}
